Supervoxels plugin for Quantiphyse
==================================

This plugin provides supervoxels clustering method for Quantiphyse

Quantiphyse must be installed. To install the plugin from PyPi use:

    pip install quantiphyse-sv

The plugin will then be available from within Quantiphyse

